nikola.plugins package
======================

.. automodule:: nikola.plugins
   :members:
   :undoc-members:
   :show-inheritance:

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   nikola.plugins.command
   nikola.plugins.compile
   nikola.plugins.misc
   nikola.plugins.task
   nikola.plugins.template

Submodules
----------

nikola.plugins.basic\_import module
-----------------------------------

.. automodule:: nikola.plugins.basic_import
   :members:
   :undoc-members:
   :show-inheritance:
